#' @title Create Forest Plot
#' @description This package uses gtable and gridExtra to overlay forest plots.
#' @name forestploter
#' @docType package
#' @author Alimu Dayimu \email{alimdayim@@hotmail.com}
#' @import grid
#' @keywords packagelibrary
#' @seealso \code{\link{grid}},\code{\link{gridExtra}}
#' @importFrom gtable gtable_add_grob gtable_add_rows gtable_add_padding gtable_add_cols
#' @importFrom gridExtra tableGrob ttheme_minimal
#' @name forestploter-package
#' @docType package
"_PACKAGE"
